#!/bin/sh

# Liquid War 6 is a unique multiplayer wargame.
# Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# 
# Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
# Contact author        : ufoot@ufoot.org

# Remove temporary & backup files

#cd ../src && find .. -name "*~" -exec echo "{}" \;
cd ../src && find .. -name "*~" -exec rm -f "{}" \;
#cd ../src && find .. -name "*-e" -exec echo "{}" \;
cd ../src && find .. -name "*-e" -exec rm -f "{}" \;
#cd ../src && find .. -name ".#*" -exec echo "{}" \;
cd ../src && find .. -name ".#*" -exec rm -f "{}" \;
#cd ../src && find .. -name ".swp" -exec echo "{}" \;
cd ../src && find .. -name ".swp" -exec rm -f "{}" \;

